summaryrefslogtreecommitdiff
path: root/util/tagbranch.sh
diff options
context:
space:
mode:
Diffstat (limited to 'util/tagbranch.sh')
-rwxr-xr-xutil/tagbranch.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/util/tagbranch.sh b/util/tagbranch.sh
index 3e196b6f25..e925ddf33a 100755
--- a/util/tagbranch.sh
+++ b/util/tagbranch.sh
@@ -29,7 +29,7 @@
# - the remote git server name shows up in 'git config -l' output in the
# line starting with "remote.cros.url="
# - firmware branch names have format of firmware-<board>-XXXXXX
# - the current branch was cut off of <remote name>/master
#
# The tag name generated by this script would be the XXXXX string with dots,
# if any, replaced by underscores.
@@ -44,10 +44,10 @@ fi
export ORIGIN_NAME="cros"
ORIGIN="$(git config "remote.${ORIGIN_NAME}.url")"
-# The last common patch between this branch and the master.
-BRANCH_POINT="$(git merge-base "${UPSTREAM}" "${ORIGIN_NAME}/master")"
+# The last common patch between this branch and main.
+BRANCH_POINT="$(git merge-base "${UPSTREAM}" "${ORIGIN_NAME}/main")"
if [[ -z "${BRANCH_POINT}" ]]; then
- echo "Failed to determine cros/master branch point" >&2
+ echo "Failed to determine cros/main branch point" >&2
exit 1
fi
@@ -56,8 +56,8 @@ TAG_BASE="$(sed 's/.*-// # drop everything up to including the last -
s/\./_/g # replace dots and dashes with underscores
' <<< "${UPSTREAM}" )"
-if [[ "${TAG_BASE}" == "master" ]]; then
- echo "Nothing to tag in master branch" >&2
+if [[ "${TAG_BASE}" == "main" ]]; then
+ echo "Nothing to tag in main branch" >&2
exit 1
fi
@@ -29,7 +29,7 @@
# line starting with "remote.cros.url="
# - firmware branch names have format of firmware-<board>-XXXXXX
-# - the current branch was cut off of <remote name>/master
+# - the current branch was cut off of <remote name>/main
#
# The tag name generated by this script would be the XXXXX string with dots,